////////////////////////////////////////////////////////////////////////
//
// BaseFilter class:
// Algoritm to produce a filtered event file having
// events with at least 1 cluster crawler cluster
//
// corey.adams@yale.edu
//
////////////////////////////////////////////////////////////////////////
#ifndef BASEFILTER_H
#define BASEFILTER_H


#include "TH1D.h"
#include <string>

/// Framework includes
#include "art/Framework/Core/EDFilter.h"
#include "art/Framework/Core/ModuleMacros.h"
#include "art/Framework/Principal/Event.h"
#include "fhiclcpp/ParameterSet.h"
#include "art/Framework/Principal/Handle.h"
#include "art/Framework/Services/Registry/ServiceHandle.h"
#include "art/Framework/Services/Optional/TFileService.h"
#include "art/Framework/Services/Optional/TFileDirectory.h"
#include "messagefacility/MessageLogger/MessageLogger.h"
#include "canvas/Persistency/Common/FindMany.h"

#include "lardataobj/RecoBase/Cluster.h"

namespace filt {

class BaseFilter : public art::EDFilter  {

public:

  explicit BaseFilter(fhicl::ParameterSet const& pset);
  virtual ~BaseFilter();


  bool filter(art::Event& evt);
  void reconfigure(fhicl::ParameterSet const& p);
  void beginJob();


private:

  std::string fCluster_label;

protected:


}; // class BaseFilter

//-------------------------------------------------
BaseFilter::BaseFilter(fhicl::ParameterSet const & pset)
{
  this->reconfigure(pset);
}

//-------------------------------------------------
BaseFilter::~BaseFilter()
{
}

//-------------------------------------------------
void BaseFilter::reconfigure(fhicl::ParameterSet const& p)
{
  fCluster_label = p.get< std::string >("ClusterLabel");
}

//-------------------------------------------------
void BaseFilter::beginJob()
{
}

//-------------------------------------------------
bool BaseFilter::filter(art::Event &evt)
{

  art::Handle< std::vector<recob::Cluster> > clusterHandle;
  evt.getByLabel(fCluster_label, clusterHandle);


  if (clusterHandle -> size() > 0) {
    //std::cout << "event passed the filter " << evt.id().event() << std::endl;
    return true;
  }
  else {
    //std::cout << "event failed the filter " << evt.id().event() << std::endl;
    return false;
  }

} // bool

DEFINE_ART_MODULE(BaseFilter)

} //namespace filt

#endif // MATCHFILTER_H
